@@ -25,7 +25,7 @@ MONOPOLE = uncertainties.ufloat((DIP_MONOPOLE, DIP_MONOPOLE_ERR))
 DIPOLE_RA = uncertainties.ufloat((DIP_RA, DIP_RA_ERR))
 DIPOLE_DEC = uncertainties.ufloat((DIP_DEC, DIP_DEC_ERR))
 
-print "Default: "
+print "Using default inputs: "
 print dipole_error.dipole_monopole()
 
 print
@@ -54,13 +54,95 @@ print "Different Amplitude/error values: "
 for amplitude_error in [0.1e-5, 2.0e-5]:
     print "Amplitude error:", amplitude_error, "\n  da/a:", \
     dipole_error.dipole_monopole(right_ascension=QSO_RA, \
-                  declination=dec_value, \
+                  declination=QSO_DEC, \
                   dipole_ra=DIPOLE_RA, \
                   dipole_dec=DIPOLE_DEC, \
                   amplitude=uncertainties.ufloat((DIP_AMPLITUDE, amplitude_error)), \
                   monopole=MONOPOLE)
         
+print 
+print "If you want to do it by hand: "
+print dipole_error.dipole_monopole(\
+        right_ascension="22h20m06.757", \
+        declination="-28d03m23.34", \
+        dipole_ra=uncertainties.ufloat((17.3, 1.0)), \
+        dipole_dec=uncertainties.ufloat((-61.0, 10.0)), \
+        amplitude=uncertainties.ufloat((0.97e-5, 0.21e-5)), \
+        monopole=uncertainties.ufloat((-0.178e-5, 0.084e-5)),\
+        )
 
+print 
+print "If you don't want error, just pass a float (note monopole term):"
+print dipole_error.dipole_monopole(\
+        right_ascension="22h20m06.757", \
+        declination="-28d03m23.34", \
+        dipole_ra=uncertainties.ufloat((17.3, 1.0)), \
+        dipole_dec=uncertainties.ufloat((-61.0, 10.0)), \
+        amplitude=uncertainties.ufloat((0.97e-5, 0.21e-5)), \
+        monopole=0.,\
+        )
+
+print 
+print "Same functionality with the two other models: z_dipole_monopole and r_dipole_monopole:"
+
+# =====================
+# = z_dipole_monopole =
+# =====================
+Z_DIP_RA = 17.5
+Z_DIP_RA_ERR = 1.0
+Z_DIP_DEC = -62.0
+Z_DIP_DEC_ERR = 10.0
+Z_DIP_PREFACTOR = 0.81e-5
+Z_DIP_PREFACTOR_ERR = 0.27e-5 # average of .26 and .28
+Z_DIP_MONOPOLE = -0.184e-5
+Z_DIP_MONOPOLE_ERR = 0.085e-5
+Z_DIP_BETA = 0.46
+Z_DIP_BETA_ERR = 0.49
+
+Z_DIPOLE_RA = uncertainties.ufloat((Z_DIP_RA, Z_DIP_RA_ERR))
+Z_DIPOLE_DEC = uncertainties.ufloat((Z_DIP_DEC, Z_DIP_DEC_ERR))
+Z_DIPOLE_PREFACTOR = uncertainties.ufloat((Z_DIP_PREFACTOR, Z_DIP_PREFACTOR_ERR))
+Z_DIPOLE_MONOPOLE = uncertainties.ufloat((Z_DIP_MONOPOLE, Z_DIP_MONOPOLE_ERR))
+Z_DIPOLE_BETA = uncertainties.ufloat((Z_DIP_BETA, Z_DIP_BETA_ERR))
+
+print "z_dipole_monopole: "
+print dipole_error.z_dipole_monopole(right_ascension=QSO_RA, \
+                      declination=QSO_DEC, \
+                      dipole_ra=Z_DIPOLE_RA, \
+                      dipole_dec=Z_DIPOLE_DEC, \
+                      prefactor=Z_DIP_PREFACTOR, \
+                      z_redshift=REDSHIFT, \
+                      beta=Z_DIP_BETA, \
+                      monopole=Z_DIP_MONOPOLE)
+
+# =====================
+# = r_dipole_monopole =
+# =====================
+R_DIP_RA = 17.5
+R_DIP_RA_ERR = 1.0
+R_DIP_DEC = -62.0
+R_DIP_DEC_ERR = 10.0
+R_DIP_AMPLITUDE = 1.1e-6 # in GLyr 
+R_DIP_AMPLITUDE_ERR = 0.2e-6 # average of asymmetric errors
+R_DIP_MONOPOLE = -0.187e-5
+R_DIP_MONOPOLE_ERR  = 0.084e-5
+
+# Uncertainties
+R_DIPOLE_AMPLITUDE = uncertainties.ufloat((R_DIP_AMPLITUDE, R_DIP_AMPLITUDE_ERR))
+R_DIPOLE_MONOPOLE = uncertainties.ufloat((R_DIP_MONOPOLE, R_DIP_MONOPOLE_ERR))
+R_DIPOLE_RA = uncertainties.ufloat((R_DIP_RA, R_DIP_RA_ERR))
+R_DIPOLE_DEC = uncertainties.ufloat((R_DIP_DEC, R_DIP_DEC_ERR))
+
+print 
+print "r_dipole_monopole"
+print dipole_error.r_dipole_monopole(right_ascension=QSO_RA, \
+                      declination=QSO_DEC, \
+                      dipole_ra=R_DIPOLE_RA, \
+                      dipole_dec=R_DIPOLE_DEC, \
+                      amplitude=R_DIPOLE_AMPLITUDE, \
+                      radial_distance=RADIAL_DISTANCE, \
+                      monopole=R_DIPOLE_MONOPOLE)
+                      
 
 # def monte_carlo(value, error):
 #     """Return a random value around value +/- error"""
@@ -96,15 +178,6 @@ for amplitude_error in [0.1e-5, 2.0e-5]:
 #     return np.radians(angles.r2d(qso.sep(dipole_sky_position)))
 # 
 # uncertainty_theta = uncertainties.wrap(theta)
-# def theta2(dipole_ra, dipole_dec, qso_ra, qso_dec):
-#     return np.radians(angles.r2d(sky_position(qso_ra, qso_dec).sep(sky_position(dipole_ra, dipole_dec))))
-# 
-# def theta3(dipole_ra, dipole_dec, qso_ra, qso_dec):
-#     # dipole_sky_position = angles.AngularPosition(alpha=dipole_ra, delta=dipole_dec)
-#     dipole_sky_position = sky_position(dipole_ra, dipole_dec)
-#     # qso_position = angles.AngularPosition(alpha=qso_ra, delta=qso_dec)
-#     qso_position = sky_position(qso_ra, qso_dec)
-#     return np.radians(angles.r2d(qso_position.sep(dipole_sky_position)))
 # 
 # uncertainty_theta = uncertainties.wrap(theta)
 # uncertainty_theta2 = uncertainties.wrap(theta2)
@@ -271,13 +344,6 @@ for amplitude_error in [0.1e-5, 2.0e-5]:
 # # # print qso_total_error
 # # # print np.sqrt(qso_total_error ** 2 + predicted_error ** 2)
 # # # 
-# # # 
-# # # # testing 
-# # # # plot(linspace(0, (2*np.pi), 360), predicted_alpha(A, linspace(0, (2*np.pi), 360), m))
-# # # 
-# # # # Test function working properly
-# # # # print A_prefactors[0] + m_values[0],  predicted_alpha(A_prefactors[0], 0, m_values[0])
-# # # 
 # # # # Test RA/DEC behaving like expected.
 # # # # test1 = angles.AngularPosition(alpha=15.3, delta=-60)
 # # # # test2 = angles.AngularPosition(alpha=15.3, delta=-40)
@@ -290,10 +356,6 @@ for amplitude_error in [0.1e-5, 2.0e-5]:
 # # # # Didn't work: 
 # # # # print predicted_alpha(A_prefactors[0], angles.r2d(qso.sep(dipole)), m_values[0])
 # # # 
-# # # # Kanekar 
-# # # 
-# # # # <markdowncell>
-# # # 
 # # # # Expected da/a at pole
 # # # # ======================
 # # # # Separation angle between dipole and qso:  0.97 degrees or 0.01693 radians.
